@@ -709,7 +709,7 @@ Kliknte na slo zlohy pro prohlen a obnoven zlohy.
     <td align="center"> Datum sputn </td>
     <td align="center"> Doba trvn/minuty </td>
     <td align="center"> Doba/dny </td>
-    <td align="center"> </td>
+    \$deleteHdrStr
     <td align="center"> Cesta serveru zlohy </td>
 </tr>
 \$str
