@@ -11,7 +11,7 @@
 #   Craig Barratt  <cbarratt@users.sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2001-2017  Craig Barratt
+#   Copyright (C) 2001-2018  Craig Barratt
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #
 #========================================================================
 #
-# Version 4.1.5, released 3 Dec 2017.
+# Version 4.2.1, released 7 May 2018.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -97,7 +97,7 @@ sub new
 
     my $bpc = bless {
 	%$paths,
-        Version => '4.1.5',
+        Version => '4.2.1',
     }, $class;
 
     $bpc->{storage} = BackupPC::Storage->new($paths);
@@ -1365,6 +1365,39 @@ sub sortedPCLogFiles
     return sort compareLOGName @files;
 }
 
+#
+# Opens a writeable file handle to the per-client's LOG file.
+# Also ages LOG files if the LOG file is new
+#
+sub openPCLogFile
+{
+    my($bpc, $client) = @_;
+    my($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime(time);
+    my $logPath = sprintf("%s/pc/%s/LOG.%02d%04d", $bpc->{TopDir}, $client, $mon + 1, $year + 1900);
+    my $logFd;
+
+    if ( !-f $logPath ) {
+        #
+        # Compress and prune old log files
+        #
+        my $lastLog = $bpc->{Conf}{MaxOldPerPCLogFiles} - 1;
+        foreach my $file ( $bpc->sortedPCLogFiles($client) ) {
+            if ( $lastLog <= 0 ) {
+                unlink($file);
+                next;
+            }
+            $lastLog--;
+            next if ( $file =~ /\.z$/ || !$bpc->{Conf}{CompressLevel} );
+            BackupPC::XS::compressCopy($file,
+                                        "$file.z",
+                                        undef,
+                                        $bpc->{Conf}{CompressLevel}, 1);
+        }
+    }
+    open($logFd, ">>", $logPath);
+    return ($logFd, $logPath);
+}
+
 #
 # converts a glob-style pattern into a perl regular expression.
 #
